#ifndef __CINT__
#include "RooGlobalFunc.h"
#endif
#include "RooRealVar.h"
#include "RooDataSet.h"
#include "RooGaussian.h"
#include "TCanvas.h"
#include "RooPlot.h"
#include "RooClassFactory.h"
#include "TROOT.h"

#include "stdio.h"
#include "time.h"

#ifndef __CINT__
#include "RooMyGE.h"
#endif

using namespace RooFit ;


void useMyGE(){
  
  // Compile MyPdfV3 class (only when running in CINT)
#ifdef __CINT__
  gROOT->ProcessLineSync(".x RooMyGE.cxx+") ;
#endif

  RooRealVar *t  = new RooRealVar( "t", "proper time", -0.2 , 3.0 , "ps" );
  RooRealVar *st = new RooRealVar("st", "proper time resolution",  0.,  0.08, "ps" );
  
  RooRealVar *stSF = new RooRealVar("S_{t}","resolutions scale",0.8, 0.1, 3);
  RooRealVar *tau = new RooRealVar("#tau", "lifetime", 0.48, 0.1, 3.0, "ps");

  // observables 
  RooArgSet* observables = new RooArgSet(*t,*st);
  
  // read in data
  RooDataSet *data = RooDataSet::read("bigData.txt",  
				      RooArgSet( *observables ) );

  RooDataSet *stData = data->reduce(*st);
  RooDataHist* stHist = stData->binnedClone() ;
  RooHistPdf stPdf("stPdf","stPdf",*st,*stHist) ;
  
  RooMyGE pdf("pdf","pdf", *t, *st, *tau, *stSF ) ;

  RooProdPdf condPdf("condPdf","condPdf",RooArgList(stPdf),Conditional(RooArgList(pdf),RooArgList(*t))) ;
  

  // fitting here
  condPdf.fitTo( *data ) ;

  RooPlot* frame1 = t->frame(Title("Pseudo proper decay time")) ;

  data->plotOn(frame1 ) ;
  condPdf.paramOn(frame1, Layout(0.58,0.99,0.99));
  condPdf.plotOn(frame1 , ProjWData(*st, *data)) ;
  //condPdf.plotOn(frame1) ;

  frame1->Draw() ;
  
}
