void useRooDecay(){

  using namespace RooFit ;

  RooRealVar *t  = new RooRealVar("t","proper time",-0.2,5.0,"ps");
  RooRealVar *st  = new RooRealVar("st","estimated proper time resolution",0.,0.08,"ps");
  
  // the set of observables...
  RooArgSet* observables = new RooArgSet(*t,*st);
  
  // Resolution function 
  RooRealVar *TauResScale = new RooRealVar("S_{t}","resolutions scale", 0.8, 0.1, 3); 
  RooRealVar *TauResBias = new RooRealVar("TauResBias","bias",0.,-5,5);
  RooRealVar *TauResBiasScale = new RooRealVar("TauResBiasScale","bias scale",1.0,0.5,3);
  RooResolutionModel *TauRes = new RooGaussModel("TauRes","gauss resolution model",
                                                 *t,*TauResBias,*st,*TauResBiasScale,*TauResScale); 

  TauResBias->setConstant(kTRUE);
  TauResBiasScale->setConstant(kTRUE);

  //
  //Singal
  //------------------------------------------------
  RooRealVar *Tau = new RooRealVar("#tau","lifetime",0.48,0.1,3.0,"ps");
  RooAbsPdf  *TauPdf = new RooDecay("TauPdf","unbiased proper time",*t,*Tau,*TauRes,RooDecay::SingleSided);

  RooDataSet *data = RooDataSet::read("bigData.txt",
				      RooArgSet( *observables ) );

  RooDataSet *stData = data->reduce(*st);
  RooDataHist* stHist = stData->binnedClone() ;
  RooHistPdf stPdf("stPdf","stPdf",*st,*stHist) ;

  RooProdPdf condTauPdf("condTauPdf","condTauPdf",RooArgList(stPdf),Conditional(RooArgList(*TauPdf),RooArgList(*t))) ;

  condTauPdf.fitTo(*data) ;

  RooPlot* frame1 = t->frame(Title("Proper decay time")) ;
  data->plotOn(frame1) ;
  condTauPdf.paramOn(frame1, Layout(0.58,0.99,0.99));
  condTauPdf.plotOn(frame1,ProjWData(*st, *data)) ;
  //condTauPdf->plotOn(frame1);

  frame1->Draw() ;
}
